"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .address import Address, AddressTypedDict
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from gr4vy.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PayoutMerchantSummaryTypedDict(TypedDict):
    r"""PayoutMerchantSummary

    Represents a summary of a merchant.
    """

    name: str
    r"""The name of the merchant."""
    identification_number: str
    r"""Unique value which identifies a merchant for processing transactions, also known as a MID."""
    phone_number: str
    r"""The phone number for the merchant which should be formatted according to the E164 number standard."""
    url: str
    r"""Merchant website URL."""
    merchant_category_code: str
    r"""Merchant classification for the type of goods or services it provides."""
    type: Literal["merchant"]
    r"""Always `merchant`."""
    statement_descriptor: NotRequired[Nullable[str]]
    r"""Value to explain charges or payments on bank statements."""
    address: NotRequired[Nullable[AddressTypedDict]]
    r"""The address for the merchant."""


class PayoutMerchantSummary(BaseModel):
    r"""PayoutMerchantSummary

    Represents a summary of a merchant.
    """

    name: str
    r"""The name of the merchant."""

    identification_number: str
    r"""Unique value which identifies a merchant for processing transactions, also known as a MID."""

    phone_number: str
    r"""The phone number for the merchant which should be formatted according to the E164 number standard."""

    url: str
    r"""Merchant website URL."""

    merchant_category_code: str
    r"""Merchant classification for the type of goods or services it provides."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["merchant"]], AfterValidator(validate_const("merchant"))
        ],
        pydantic.Field(alias="type"),
    ] = "merchant"
    r"""Always `merchant`."""

    statement_descriptor: OptionalNullable[str] = UNSET
    r"""Value to explain charges or payments on bank statements."""

    address: OptionalNullable[Address] = UNSET
    r"""The address for the merchant."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["type", "statement_descriptor", "address"]
        nullable_fields = ["statement_descriptor", "address"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from typing_extensions import TypedDict


class GooglePaySessionRequestTypedDict(TypedDict):
    origin_domain: str
    r"""The domain on which Google Pay is being loaded."""


class GooglePaySessionRequest(BaseModel):
    origin_domain: str
    r"""The domain on which Google Pay is being loaded."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .giftcardsummary import GiftCardSummary, GiftCardSummaryTypedDict
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class GiftCardSummariesTypedDict(TypedDict):
    items: List[GiftCardSummaryTypedDict]
    r"""A list of items returned for this request."""


class GiftCardSummaries(BaseModel):
    items: List[GiftCardSummary]
    r"""A list of items returned for this request."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cardscheme import CardScheme
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from gr4vy.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class MerchantAccountUpdateTypedDict(TypedDict):
    account_updater_enabled: NotRequired[bool]
    r"""Whether the Real-Time Account Updater service is enabled for this merchant account. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `false`, the Account Updater service doesn't get called if a payment fails with expired or invalid card details. If the field is set to `true`, the service is called. Please note that for this to work the other `account_updater_* fields` must be set as well."""
    account_updater_request_encryption_key: NotRequired[Nullable[str]]
    r"""The public key used to encrypt the request to the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""
    account_updater_request_encryption_key_id: NotRequired[Nullable[str]]
    r"""The ID of the key used to encrypt the request to the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""
    account_updater_response_decryption_key: NotRequired[Nullable[str]]
    r"""The key used to decrypt the response from the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""
    account_updater_response_decryption_key_id: NotRequired[Nullable[str]]
    r"""The ID of the key used to decrypt the request from the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""
    over_capture_amount: NotRequired[Nullable[int]]
    r"""The maximum monetary amount allowed for over-capture, in the smallest currency unit, for example `1299` cents to allow for an over-capture of `$12.99`."""
    over_capture_percentage: NotRequired[Nullable[int]]
    r"""The maximum percentage allowed for over-capture, for example `25` to allow for an over-capture of `25%` of the original transaction amount."""
    loon_client_key: NotRequired[Nullable[str]]
    r"""Client key provided by Pagos to authenticate to the Loon API. Loon is the Account Updater service we use and if the field is not set or if it's set to null, the Account Updater service doesn't get configured. If the field is set to `null`, the other `loon_*` fields must be set to null as well."""
    loon_secret_key: NotRequired[Nullable[str]]
    r"""Secret key provided by Pagos to authenticate to the Loon API. Loon is the Account Updater service we use and if the field is not set or if it's set to null, the Account Updater service doesn't get configured. If the field is set to `null`, the other `loon_*` fields must be set to null as well."""
    loon_accepted_schemes: NotRequired[Nullable[List[CardScheme]]]
    r"""Card schemes accepted when creating jobs using this set of Loon API keys. Loon is the Account Updater service we use and if the field is not set or if it's set to null, the Account Updater service doesn't get configured. If the field is set to `null`, the other `loon_*` fields must be set to null as well."""
    visa_network_tokens_requestor_id: NotRequired[Nullable[str]]
    r"""Requestor ID provided for Visa after onboarding to use Network Tokens."""
    visa_network_tokens_app_id: NotRequired[Nullable[str]]
    r"""Application ID provided for Visa after onboarding to use Network Tokens."""
    amex_network_tokens_requestor_id: NotRequired[Nullable[str]]
    r"""Requestor ID provided for American Express after onboarding to use Network Tokens."""
    amex_network_tokens_app_id: NotRequired[Nullable[str]]
    r"""Application ID provided for American Express after onboarding to use Network Tokens."""
    mastercard_network_tokens_requestor_id: NotRequired[Nullable[str]]
    r"""Requestor ID provided for Mastercard after onboarding to use Network Tokens."""
    mastercard_network_tokens_app_id: NotRequired[Nullable[str]]
    r"""Application ID provided for Mastercard after onboarding to use Network Tokens."""
    async_network_tokens_enabled: NotRequired[bool]
    r"""When enabled network tokens will be generated asynchronously and only used on subsequent transactions to speed up transaction processing."""
    display_name: NotRequired[Nullable[str]]
    r"""The display name for the merchant account."""


class MerchantAccountUpdate(BaseModel):
    account_updater_enabled: Optional[bool] = False
    r"""Whether the Real-Time Account Updater service is enabled for this merchant account. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `false`, the Account Updater service doesn't get called if a payment fails with expired or invalid card details. If the field is set to `true`, the service is called. Please note that for this to work the other `account_updater_* fields` must be set as well."""

    account_updater_request_encryption_key: OptionalNullable[str] = UNSET
    r"""The public key used to encrypt the request to the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""

    account_updater_request_encryption_key_id: OptionalNullable[str] = UNSET
    r"""The ID of the key used to encrypt the request to the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""

    account_updater_response_decryption_key: OptionalNullable[str] = UNSET
    r"""The key used to decrypt the response from the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""

    account_updater_response_decryption_key_id: OptionalNullable[str] = UNSET
    r"""The ID of the key used to decrypt the request from the Real-Time Account Updater service. The Account Updater service is used to update card details when cards are lost, stolen or expired. If the field is not set or if it's set to `null`, the Account Updater service doesn't get called. If the field is set, the other `account_updater_*` fields must be set as well."""

    over_capture_amount: OptionalNullable[int] = UNSET
    r"""The maximum monetary amount allowed for over-capture, in the smallest currency unit, for example `1299` cents to allow for an over-capture of `$12.99`."""

    over_capture_percentage: OptionalNullable[int] = UNSET
    r"""The maximum percentage allowed for over-capture, for example `25` to allow for an over-capture of `25%` of the original transaction amount."""

    loon_client_key: OptionalNullable[str] = UNSET
    r"""Client key provided by Pagos to authenticate to the Loon API. Loon is the Account Updater service we use and if the field is not set or if it's set to null, the Account Updater service doesn't get configured. If the field is set to `null`, the other `loon_*` fields must be set to null as well."""

    loon_secret_key: OptionalNullable[str] = UNSET
    r"""Secret key provided by Pagos to authenticate to the Loon API. Loon is the Account Updater service we use and if the field is not set or if it's set to null, the Account Updater service doesn't get configured. If the field is set to `null`, the other `loon_*` fields must be set to null as well."""

    loon_accepted_schemes: OptionalNullable[
        List[Annotated[CardScheme, PlainValidator(validate_open_enum(False))]]
    ] = UNSET
    r"""Card schemes accepted when creating jobs using this set of Loon API keys. Loon is the Account Updater service we use and if the field is not set or if it's set to null, the Account Updater service doesn't get configured. If the field is set to `null`, the other `loon_*` fields must be set to null as well."""

    visa_network_tokens_requestor_id: OptionalNullable[str] = UNSET
    r"""Requestor ID provided for Visa after onboarding to use Network Tokens."""

    visa_network_tokens_app_id: OptionalNullable[str] = UNSET
    r"""Application ID provided for Visa after onboarding to use Network Tokens."""

    amex_network_tokens_requestor_id: OptionalNullable[str] = UNSET
    r"""Requestor ID provided for American Express after onboarding to use Network Tokens."""

    amex_network_tokens_app_id: OptionalNullable[str] = UNSET
    r"""Application ID provided for American Express after onboarding to use Network Tokens."""

    mastercard_network_tokens_requestor_id: OptionalNullable[str] = UNSET
    r"""Requestor ID provided for Mastercard after onboarding to use Network Tokens."""

    mastercard_network_tokens_app_id: OptionalNullable[str] = UNSET
    r"""Application ID provided for Mastercard after onboarding to use Network Tokens."""

    async_network_tokens_enabled: Optional[bool] = False
    r"""When enabled network tokens will be generated asynchronously and only used on subsequent transactions to speed up transaction processing."""

    display_name: OptionalNullable[str] = UNSET
    r"""The display name for the merchant account."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "account_updater_enabled",
            "account_updater_request_encryption_key",
            "account_updater_request_encryption_key_id",
            "account_updater_response_decryption_key",
            "account_updater_response_decryption_key_id",
            "over_capture_amount",
            "over_capture_percentage",
            "loon_client_key",
            "loon_secret_key",
            "loon_accepted_schemes",
            "visa_network_tokens_requestor_id",
            "visa_network_tokens_app_id",
            "amex_network_tokens_requestor_id",
            "amex_network_tokens_app_id",
            "mastercard_network_tokens_requestor_id",
            "mastercard_network_tokens_app_id",
            "async_network_tokens_enabled",
            "display_name",
        ]
        nullable_fields = [
            "account_updater_request_encryption_key",
            "account_updater_request_encryption_key_id",
            "account_updater_response_decryption_key",
            "account_updater_response_decryption_key_id",
            "over_capture_amount",
            "over_capture_percentage",
            "loon_client_key",
            "loon_secret_key",
            "loon_accepted_schemes",
            "visa_network_tokens_requestor_id",
            "visa_network_tokens_app_id",
            "amex_network_tokens_requestor_id",
            "amex_network_tokens_app_id",
            "mastercard_network_tokens_requestor_id",
            "mastercard_network_tokens_app_id",
            "display_name",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from gr4vy.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Literal, Union
from typing_extensions import Annotated, NotRequired, TypedDict


UserDevice = Union[
    Literal[
        "desktop",
        "mobile",
    ],
    UnrecognizedStr,
]
r"""The platform that is being used to access the website."""


class BrowserInfoTypedDict(TypedDict):
    r"""Merchant provided browser info"""

    javascript_enabled: bool
    java_enabled: bool
    language: str
    color_depth: int
    screen_height: int
    screen_width: int
    time_zone_offset: int
    user_agent: str
    r"""Exact content of the HTTP user-agent header."""
    user_device: UserDevice
    r"""The platform that is being used to access the website."""
    accept_header: NotRequired[Nullable[str]]
    r"""The Accept header of the request from the buyer's browser."""


class BrowserInfo(BaseModel):
    r"""Merchant provided browser info"""

    javascript_enabled: bool

    java_enabled: bool

    language: str

    color_depth: int

    screen_height: int

    screen_width: int

    time_zone_offset: int

    user_agent: str
    r"""Exact content of the HTTP user-agent header."""

    user_device: Annotated[UserDevice, PlainValidator(validate_open_enum(False))]
    r"""The platform that is being used to access the website."""

    accept_header: OptionalNullable[str] = UNSET
    r"""The Accept header of the request from the buyer's browser."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["accept_header"]
        nullable_fields = ["accept_header"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from gr4vy.types import BaseModel
from typing_extensions import TypedDict


class ReportExecutionContextTypedDict(TypedDict):
    reference_timestamp: datetime
    r"""The reference timestamp for the report execution context."""
    reference_timezone: str
    r"""The reference timezone for the report execution context."""


class ReportExecutionContext(BaseModel):
    reference_timestamp: datetime
    r"""The reference timestamp for the report execution context."""

    reference_timezone: str
    r"""The reference timezone for the report execution context."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from gr4vy.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Any, Dict
from typing_extensions import Annotated, TypedDict


class CreatePaymentServiceDefinitionSessionRequestTypedDict(TypedDict):
    payment_service_definition_id: str
    request_body: Dict[str, Any]


class CreatePaymentServiceDefinitionSessionRequest(BaseModel):
    payment_service_definition_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        Dict[str, Any],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from gr4vy.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PlaidPaymentMethodCreateTypedDict(TypedDict):
    r"""Plaid Payment Method

    Plaid Payment Method to use in a transaction.
    """

    token: str
    r"""The public token obtained after using Plaid Link."""
    method: Literal["plaid"]
    r"""Always `plaid`."""
    account_id: NotRequired[Nullable[str]]
    r"""The Plaid account ID corresponding to the end-user account. If not provided will be fetched from Plaid API expecting to only have one."""
    payment_service_id: NotRequired[Nullable[str]]
    r"""The ID of the Plaid payment service related to the provided public token. If not provided will be fetched from the currently active expecting to have a single one."""
    buyer_id: NotRequired[Nullable[str]]
    r"""The ID of the buyer to attach the method to."""
    buyer_external_identifier: NotRequired[Nullable[str]]
    r"""The merchant reference for this payment method."""
    external_identifier: NotRequired[Nullable[str]]
    r"""The merchant identifier for this payment method."""


class PlaidPaymentMethodCreate(BaseModel):
    r"""Plaid Payment Method

    Plaid Payment Method to use in a transaction.
    """

    token: str
    r"""The public token obtained after using Plaid Link."""

    METHOD: Annotated[
        Annotated[Optional[Literal["plaid"]], AfterValidator(validate_const("plaid"))],
        pydantic.Field(alias="method"),
    ] = "plaid"
    r"""Always `plaid`."""

    account_id: OptionalNullable[str] = UNSET
    r"""The Plaid account ID corresponding to the end-user account. If not provided will be fetched from Plaid API expecting to only have one."""

    payment_service_id: OptionalNullable[str] = UNSET
    r"""The ID of the Plaid payment service related to the provided public token. If not provided will be fetched from the currently active expecting to have a single one."""

    buyer_id: OptionalNullable[str] = UNSET
    r"""The ID of the buyer to attach the method to."""

    buyer_external_identifier: OptionalNullable[str] = UNSET
    r"""The merchant reference for this payment method."""

    external_identifier: OptionalNullable[str] = UNSET
    r"""The merchant identifier for this payment method."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "method",
            "account_id",
            "payment_service_id",
            "buyer_id",
            "buyer_external_identifier",
            "external_identifier",
        ]
        nullable_fields = [
            "account_id",
            "payment_service_id",
            "buyer_id",
            "buyer_external_identifier",
            "external_identifier",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
